@@ -1,5 +1,5 @@
 <map version="freeplane 1.5.9">
-<!--To view this file, download free mind mapping software Freeplane from http://freeplane.sourceforge.net -->
+<!--To view this file, download free mind mapping software Freeplane from https://www.freeplane.org -->
 <node TEXT="Freeplane 1.2&#xa;Functions" FOLDED="false" ID="ID_45488473" CREATED="1288535648658" MODIFIED="1323787510068" BACKGROUND_COLOR="#00ff99" VGAP_QUANTITY="0.0 px">
 <icon BUILTIN="bee"/>
 <font BOLD="true"/>
@@ -183,9 +183,6 @@
       <li>
         <i>Help &gt;  </i><i>Tutorial</i>&#160;<a href="freeplaneTutorial.mm#ID_1337127972">Basic map</a>
       </li>
-      <li>
-        <i>Help &gt; Documentation</i>&#160;<a href="freeplane.mm#ID_1154882439">Edit &gt; Node core</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -219,9 +216,6 @@
       <li>
         <i>Help &gt;  </i><i>Tutorial</i>&#160;<a href="freeplaneTutorial.mm#ID_265318117">Edit &gt; Node core text</a>&#160;
       </li>
-      <li>
-        <i>Help &gt; Documentation: Menu</i>&#160;&#160;<a href="freeplane.mm#ID_1162372089">Edit &gt; Node core &gt; text...</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -254,10 +248,7 @@
     </p>
     <ul>
       <li>
-        <i>Help &gt;  </i><i>Tutorial</i>&#160;<a href="http://freeplaneTutorial.mm#ID_1795262306">Image (node core)</a>
-      </li>
-      <li>
-        <i>Help &gt; Documentation</i>&#160;<a href="http://freeplane.mm#ID_1277752024">Edit &gt; Node core &gt; Image</a>
+        <i>Help &gt;  </i><i>Tutorial</i>&#160;<a href="freeplaneTutorial.mm#ID_1795262306">Image (node core)</a>
       </li>
     </ul>
   </body>
@@ -293,9 +284,6 @@
       <li>
         <i>Help &gt;  </i><i>Tutorial</i>&#160;<a href="freeplaneTutorial.mm#ID_1830541497">Green arrow link</a>&#160;
       </li>
-      <li>
-        <i>Help &gt; Documentation: Menu</i>&#160;&#160;<a href="freeplane.mm#ID_271903009">Edit &gt; Link &gt; Add local hyperlink</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -317,9 +305,6 @@
       <li>
         <i>Help &gt;  </i><i>Tutorial</i>&#160;<a href="freeplaneTutorial.mm#ID_1913035829">Red arrow link</a>&#160;
       </li>
-      <li>
-        <i>Help &gt; Documentation: Menu</i>&#160;&#160;<a href="freeplane.mm#ID_178833757">Edit &gt; Link &gt; Add hyperlink</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -344,9 +329,6 @@
       <li>
         <i>Help &gt;  </i><i>Tutorial</i>&#160;<a href="freeplaneTutorial.mm#ID_715025500">Icons</a>&#160;
       </li>
-      <li>
-        <i>Help &gt; Documentation: Menu</i>&#160;&#160;<a href="freeplane.mm#ID_835126969">Edit &gt; Node core &gt; Icon...</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -368,9 +350,7 @@
       <li>
         <i>Help &gt;  </i><i>Tutorial</i>&#160;<a href="freeplaneTutorial.mm#ID_707469329">Progress</a>&#160;
       </li>
-      <li>
-        <i>Help &gt; Documentation: Menu</i>&#160;&#160;<a href="freeplane.mm#ID_1053622072">Edit &gt; Node core &gt; Progress.</a>
-      </li>
+
     </ul>
   </body>
 </html>
@@ -391,6 +371,7 @@
       <li>
         <i>Help &gt;  </i><i>Tutorial</i>&#160;<a href="freeplaneTutorial.mm#ID_1531819965">Automatic node numbering</a>&#160;
       </li>
+
     </ul>
   </body>
 </html>
@@ -413,6 +394,7 @@
       <li>
         <a href="freeplaneTutorial.mm#ID_15604512"><i>Tutorial</i></a>
       </li>
+
     </ul>
   </body>
 </html>
@@ -436,9 +418,6 @@
       <li>
         <i>Help &gt;  </i><i>Tutorial</i>&#160;<a href="freeplaneTutorial.mm#ID_128387683">Free (floating) node</a>
       </li>
-      <li>
-        <i>Help &gt; Documentation:</i>&#160;<a href="freeplane.mm#ID_572207726">Edit&#160;&gt; Free positioned node (set/reset)</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -472,9 +451,6 @@
       <li>
         <i>Help &gt;  </i><i>Tutorial</i>&#160;<a href="freeplaneTutorial.mm#ID_128387683">Free (floating) node</a>
       </li>
-      <li>
-        <i>Help &gt; Documentation: </i>Menu&#160;<a href="freeplane.mm#ID_114978489">Format&#160;&gt; Apply style &gt; Floating node</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -524,9 +500,6 @@
       <li>
         <i>Help &gt;  </i><i>Tutorial</i>&#160;<a href="freeplaneTutorial.mm#ID_128387683">Free (floating) node</a>
       </li>
-      <li>
-        <i>Help &gt; Documentation:</i>&#160;<a href="freeplane.mm#ID_572207726">Edit&#160;&gt; Free positioned node (set/reset)</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -564,9 +537,6 @@
       <li>
         <i>Help &gt;  </i><i>Tutorial</i>&#160;<a href="freeplaneTutorial.mm#ID_143196514">Node extensions</a>
       </li>
-      <li>
-        <i>Help &gt; Documentation:</i>&#160;<a href="freeplane.mm#ID_1400990107">Edit&#160;&#160;&gt; Node extensions</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -584,7 +554,7 @@
   </head>
   <body>
     <p>
-      <b>Text </b>&#160;with <a href="http://www.freeplane.org">in-line</a>&#160;hyperlink(s), and:
+      <b>Text </b>&#160;with <a href="https://www.freeplane.org">in-line</a>&#160;hyperlink(s), and:
     </p>
   </body>
 </html>
@@ -621,9 +591,6 @@
       <li>
         <i>Help &gt; <b>&#160;</b></i><b><i>Tutorial</i></b>&#160;<a href="freeplaneTutorial.mm#ID_898889730">Edit text in node details</a>
       </li>
-      <li>
-        <i>Help &gt; Documentation<b>&#160;</b></i><b>Menu</b><i>&#160;</i>&#160;<a href="freeplane.mm#ID_742575187">Edit &gt; Node extensions &gt; Edit node detalis in-line/ in dialog</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -669,12 +636,6 @@
       <li>
         <i>Help &gt;  </i><i>Tutorial</i> <a href="freeplaneTutorial.mm#ID_288274844">Show in tool tip (hover text)</a>
       </li>
-      <li>
-        <i>Help &gt; Documentation</i>&#160;<a href="freeplane.mm#ID_180063018">View &gt; Minimize node</a>
-      </li>
-      <li>
-        <i>Help &gt; Documentation</i>&#160;<a href="freeplane.mm#ID_152459666">View &gt; Tool tips &gt; Display tooltips</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -697,12 +658,6 @@
       <li>
         <i>Help &gt; <b>&#160;</b></i><b><i>Tutorial</i></b>&#160;<a href="freeplaneTutorial.mm#ID_1324773677">Attributes in node extensions</a>
       </li>
-      <li>
-        <i>Help &gt; Documentation<b>&#160;</b></i><b>Menu</b><i>&#160;</i>&#160;<a href="freeplane.mm#ID_147715298">Edit &gt; Attributes</a>
-      </li>
-      <li>
-        <i>Help &gt; Documentation<b>&#160;</b></i><b>Menu</b><i>&#160;</i>&#160;<a href="freeplane.mm#ID_353026241">View &gt;&#160;&#160;Attributes</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -737,9 +692,6 @@
       <li>
         <i>Help &gt; <b>&#160;</b></i><b><i>Tutorial</i></b>&#160;<a href="freeplaneTutorial.mm#ID_616494746">Scientific formula</a>
       </li>
-      <li>
-        <i>Help &gt; Documentation<b>&#160;</b></i><b>Menu</b><i>&#160;</i>&#160;<a href="freeplane.mm#ID_1750517188">Edit &gt; Node extensions &gt; LaTeX formula</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -777,9 +729,6 @@
       <li>
         <i>Help &gt; <b>&#160;</b></i><b><i>Tutorial</i></b>&#160;<a href="freeplaneTutorial.mm#ID_575269438">Image</a>
       </li>
-      <li>
-        <i>Help &gt; Documentation<b>&#160;</b></i><b>Menu</b><i>&#160;</i>&#160;<a href="freeplane.mm#ID_1620391394">Edit &gt; Node extensions &gt; Image?</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -823,14 +772,7 @@
     <p>
       <b>See</b>
     </p>
-    <ul>
-      <li>
-        <i>Help &gt; <b>&#160;</b></i><b><i>Tutorial</i>&#160;<a href="freeplaneTutorial.mm#ID_1812601804">Tool panel,</a>&#160;</b>&#160;<a href="freeplanefreeplane.mm#ID_1492225657">Edges</a>&#160;and <a href="freeplaneTutorial.mm#ID_1005719714">Automatic edge colour</a>
-      </li>
-      <li>
-        <i>Help &gt; Documentation<b>&#160;</b></i><b>Menu</b><i>&#160;</i>&#160;<a href="freeplane.mm#ID_881523974">Format &gt; Edge styles/width/colour; automatic edge colour</a>
-      </li>
-    </ul>
+    <ul>    </ul>
   </body>
 </html>
 </richcontent>
@@ -901,9 +843,6 @@
       <li>
         <i>Help &gt;  </i><i>Tutorial</i>&#160;<a href="freeplaneTutorial.mm#ID_274601394">Note</a>&#160;
       </li>
-      <li>
-        <i>Help &gt; Documentation: Menu</i>&#160;&#160;<a href="freeplane.mm#ID_1365598976">Edit &gt; Note</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -925,9 +864,6 @@
       <li>
         <i>Help &gt; <b>&#160;</b></i><b><i>Tutorial</i></b>&#160;<a href="freeplaneTutorial.mm#ID_1150908697">Cloud node group</a>
       </li>
-      <li>
-        <i>Help &gt; Documentation<b>&#160;</b></i><b>Menu</b><i>&#160;</i>&#160;<a href="freeplane.mm#ID_1759348470">Format &gt; Cloud properties</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -949,9 +885,6 @@
       <li>
         <i>Help &gt;  </i><i>Tutorial</i>&#160;<a href="freeplaneTutorial.mm#ID_1150908697">Cloud node group</a>
       </li>
-      <li>
-        <i>Help &gt; Documentation:</i>&#160;<a href="freeplane.mm#ID_759607649">View&#160;&#160;&gt; Add cloud or change style</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -973,9 +906,6 @@
       <li>
         <i>Help &gt;  </i><i>Tutorial</i>&#160;<a href="freeplaneTutorial.mm#ID_1150908697">Cloud node group</a>
       </li>
-      <li>
-        <i>Help &gt; Documentation:</i>&#160;<a href="freeplane.mm#ID_759607649">View&#160;&#160;&gt; Add cloud or change style</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -1096,9 +1026,6 @@
       <li>
         <i>Help &gt; <b>&#160;</b></i><b><i>Tutorial</i></b>&#160;<a href="freeplaneTutorial.mm#ID_1073407528">Connector</a>
       </li>
-      <li>
-        <i>Help &gt; Documentation<b>&#160;</b></i><b>Menu</b><i>&#160;</i>&#160;<a href="freeplane.mm#ID_1803275985">Edit &gt; Connect</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -1122,9 +1049,6 @@
       <li>
         <i>Help &gt; <b>&#160;</b></i><b><i>Tutorial</i></b>&#160;<a href="freeplaneTutorial.mm#ID_1073407528">Connector</a>
       </li>
-      <li>
-        <i>Help &gt; Documentation<b>&#160;</b></i><b>Menu</b><i>&#160;</i>&#160;<a href="freeplane.mm#ID_1803275985">Edit &gt; Connect</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -1169,9 +1093,6 @@
       <li>
         <i>Help &gt; <b>&#160;</b></i><b><i>Tutorial</i></b>&#160;<a href="freeplaneTutorial.mm#ID_1073407528">Connector</a>
       </li>
-      <li>
-        <i>Help &gt; Documentation<b>&#160;</b></i><b>Menu</b><i>&#160;</i>&#160;<a href="freeplane.mm#ID_1803275985">Edit &gt; Connect</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -1191,9 +1112,6 @@
       <li>
         <i>Help &gt;  </i><i>Tutorial</i>&#160;<a href="freeplaneTutorial.mm#ID_1778719162">Formatting and styling</a>
       </li>
-      <li>
-        <i>Help &gt; Documentation:</i>&#160;<a href="freeplane.mm#ID_39827582">Format &gt; Node core</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -1266,9 +1184,6 @@
       <li>
         <i>Help &gt;  </i><i>Tutorial</i>&#160;<a href="freeplaneTutorial.mm#ID_1232153769">Protecting nodes</a>
       </li>
-      <li>
-        <i>Help &gt; Documentation: </i>Menu&#160;<a href="freeplane.mm#ID_83654353">Tools &gt; Password protection</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -1302,9 +1217,6 @@
       <li>
         <i>Help &gt;  </i><i>Tutorial</i>&#160;<a href="freeplaneTutorial.mm#ID_448338872">Perform calculation</a>
       </li>
-      <li>
-        <i>Help &gt; Documentation: Wiki</i>&#160;<a href="freeplane.mm#ID_1130453106">Formula evaluation</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -1361,9 +1273,6 @@
       <li>
         <i>Help &gt;  </i><i>Tutorial</i>&#160;<a href="freeplaneTutorial.mm#ID_1959496513">Date and time actions</a>
       </li>
-      <li>
-        <i>Help &gt; Documentation: Menu</i>&#160;<a href="freeplane.mm#ID_1959496513">Tools &gt; Time management</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -1399,9 +1308,6 @@
       <li>
         <i>Help &gt;  </i><i>Tutorial</i>&#160;<a href="freeplaneTutorial.mm#ID_828862571">Filtering and finding nodes</a>&#160;resp. <a href="freeplaneTutorial.mm#ID_1014457432">Sorting</a>
       </li>
-      <li>
-        <i>Help &gt; Documentation: Menu</i>&#160;<a href="freeplane.mm#ID_1254354349">Filter</a>&#160;&#160;resp. <a href="freeplane.mm#ID_1942706169">Edit &gt; Move and sort</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -1436,9 +1342,6 @@
       <li>
         <i>Help &gt;  </i><i>Tutorial</i>&#160;<a href="freeplaneTutorial.mm#ID_1268042238">Template-like information</a>&#160;resp. <a href="freeplaneTutorial.mm#ID_1838680824">Styles</a>
       </li>
-      <li>
-        <i>Help &gt; Documentation: Menu</i>&#160;<a href="freeplane.mm#ID_258919699">Format</a>&#160;&#160;resp. <a href="freeplane.mm#ID_1796388799">Templates</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -1459,9 +1362,6 @@
       <li>
         <i>Help &gt;  </i><i>Tutorial</i><i>&#160;<a href="freeplaneTutorial.mm#ID_1613405030">7. Publishing and sharing</a></i>
       </li>
-      <li>
-        <i>Help &gt; Documentation:</i>&#160;&#160;<a href="freeplane.mm#ID_1111281504">Publish images</a>&#160;&#160;resp. <a href="freeplane.mm#ID_126764093">Publish on a website or share</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -1495,9 +1395,6 @@
       <li>
         <i>Help &gt;  </i><i>Tutorial</i>&#160;<a href="freeplaneTutorial.mm#ID_519455593">Writing and using scripts</a>&#160;resp. <a href="freeplaneTutorial.mm#ID_1156954596">Add-ons</a>
       </li>
-      <li>
-        <i>Help &gt; Documentation: Menu</i>&#160;<a href="freeplane.mm#ID_1890181858">Tools &gt; Scripts</a>&#160;&#160;resp. <a href="freeplane.mm#ID_100406395">Tools &gt; Add-ons</a>
-      </li>
     </ul>
   </body>
 </html>
@@ -1532,6 +1429,7 @@
       <li>
         <i>Help &gt;  </i><i>Tutorial</i>&#160;<a href="freeplaneTutorial.mm#ID_141336344">Spelling dictionaries</a>&#160;resp. <a href="freeplaneTutorial.mm#ID_170927482">Academic writing suite</a>
       </li>
+
     </ul>
   </body>
 </html>
@@ -1557,9 +1455,6 @@
       <li>
         <i>Help &gt;  </i><i>Tutorial</i>&#160;<a href="http://freeplaneTutorial.mm#ID_651594550">Summary node group</a>
       </li>
-      <li>
-        <i>Help &gt; Documentation:</i>&#160;<a href="http://freeplane.mm#ID_1700918771">Edit&#160;&gt; Node group &gt; New summary node group (selected nodes)</a>
-      </li>
     </ul>
   </body>
 </html>
