@@ -32,7 +32,7 @@ import org.freeplane.core.ui.LengthUnits;
 import org.freeplane.core.util.Quantity;
 import org.freeplane.features.icon.IconController;
 import org.freeplane.features.icon.UIIcon;
-import org.freeplane.features.icon.factory.ImageIconFactory;
+import org.freeplane.features.icon.factory.IconFactory;
 import org.freeplane.features.map.NodeModel;
 
 public class MultipleImage implements Icon {
@@ -54,7 +54,7 @@ public class MultipleImage implements Icon {
 
 	public void addLinkIcon(Icon icon, NodeModel node) {
 		final Quantity<LengthUnits> iconHeight = IconController.getController().getIconSize(node);
-		final ImageIconFactory iconFactory = ImageIconFactory.getInstance();
+		final IconFactory iconFactory = IconFactory.getInstance();
 		final Icon scaledIcon = iconFactory.canScaleIcon(icon) ? iconFactory.getScaledIcon(icon, iconHeight) : icon;
 		mIcons.add(scaledIcon);
 		mUIIcons.add(null);
