@@ -6,6 +6,7 @@ import javax.swing.AbstractButton;
 import javax.swing.Icon;
 
 import org.freeplane.core.ui.LengthUnits;
+import org.freeplane.core.ui.svgicons.FreeplaneIconFactory;
 import org.freeplane.core.util.Quantity;
 import org.freeplane.features.icon.factory.IconFactory;
 
@@ -18,7 +19,7 @@ class MenuIconScaling {
 			final Font font = actionComponent.getFont();
 			final int fontHeight = actionComponent.getFontMetrics(font).getHeight();
 			final Quantity<LengthUnits> iconHeight = new Quantity<LengthUnits>(1.2 * fontHeight, LengthUnits.px);
-			actionComponent.setIcon(imageIconFactory.getScaledIcon(icon, iconHeight));
+			actionComponent.setIcon(FreeplaneIconFactory.toImageIcon(imageIconFactory.getScaledIcon(icon, iconHeight)));
 		}
 	}
 }
\ No newline at end of file
