@@ -21,7 +21,6 @@ package org.freeplane.features.attribute;
 
 import org.freeplane.core.ui.LengthUnits;
 import org.freeplane.core.util.Quantity;
-import org.freeplane.features.map.NodeModel;
 
 /**
  * @author Dimitry Polivaev
@@ -29,9 +28,9 @@ import org.freeplane.features.map.NodeModel;
 public interface IAttributeTableModel {
 	Quantity<LengthUnits> getColumnWidth(int col);
 
-	NodeModel getNode();
-
 	int getRowCount();
 
 	Object getValueAt(int row, int col);
+
+	Attribute getAttribute(int row);
 }
