@@ -22,10 +22,13 @@ package org.freeplane.features.icon.factory;
 import java.io.File;
 import java.io.FilenameFilter;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collections;
+import java.util.Comparator;
 import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.regex.Pattern;
 
 import org.freeplane.core.resources.ResourceController;
 import org.freeplane.core.util.LogUtils;
@@ -51,6 +54,8 @@ public class IconStoreFactory {
 	private static final String GROUP_KEY = "icons.group.%s";
 	private static final String GROUP_ICON_KEY = "IconGroupPopupAction.%s.icon";
 	private static final String GROUP_DESC_KEY = "IconGroupPopupAction.%s.text";
+	private static final Pattern iconFileNamePattern = Pattern.compile(".*\\.(svg|png)$", Pattern.CASE_INSENSITIVE);
+
 	public static IconStore ICON_STORE;
 	static {
 		ICON_STORE = new IconStore();
@@ -108,9 +113,16 @@ public class IconStoreFactory {
 	private static List<MindIcon> getUserIcons(final File iconDir, final String dir) {
 		final String[] userIconArray = iconDir.list(new FilenameFilter() {
 			public boolean accept(final File dir, final String name) {
-				return name.matches("(?i).*\\.(svg|png)$") || new File(dir, name).isDirectory();
+				return hasValidIconFileExtension(name) || new File(dir, name).isDirectory();
 			}
 		});
+		Arrays.sort(userIconArray, new Comparator<String>() {
+			@Override
+			public int compare(String o1, String o2) {
+				return getIconFileNameWithoutExtension(o1).compareTo(getIconFileNameWithoutExtension(o2));
+			}
+		});
+
 		if (userIconArray == null) {
 			return Collections.emptyList();
 		}
@@ -139,4 +151,13 @@ public class IconStoreFactory {
 		}
 		return icons;
 	}
+
+	private static boolean hasValidIconFileExtension(final String name) {
+		return iconFileNamePattern.matcher(name).matches();
+	}
+
+	private static String getIconFileNameWithoutExtension(final String fileNameWithExtension) {
+		return hasValidIconFileExtension(fileNameWithExtension) ?
+				fileNameWithExtension.substring(0, fileNameWithExtension.length() - 4) : fileNameWithExtension;
+	}
 }
