@@ -120,6 +120,36 @@ public class LinkController extends SelectionController implements IExtension {
 		this.modeController = modeController;
 	}
 
+	private static final String FILE_PROTOCOL = "file:";
+	public static URI toUri(Object object) {
+		if (object instanceof URI)
+			return (URI)object;
+		final String objectAsFileReference;
+		if(object instanceof File) {
+			objectAsFileReference = FILE_PROTOCOL + ((File)object).getPath();
+		}
+		else if(object instanceof URL) {
+			try {
+				return ((URL)object).toURI();
+			} catch (URISyntaxException e) {
+				return null;
+			}
+		}
+		else if (object instanceof String) {
+			objectAsFileReference = (String) object;
+			if(!objectAsFileReference.startsWith(FILE_PROTOCOL))
+				return null;
+		}
+		else
+			return null;
+		try {
+			return createURI(objectAsFileReference);
+		}
+		catch (URISyntaxException e) {
+			return null;
+		}
+	}
+
 	protected void init() {
 		createActions();
 		final MapController mapController = modeController.getMapController();
@@ -319,7 +349,7 @@ public class LinkController extends SelectionController implements IExtension {
 		return model.getColor();
 	}
 
-	public int[] getDash(final ConnectorModel model) {
+	public int[] getDashArray(final ConnectorModel model) {
 		return model.getDash();
 	}
 
@@ -791,13 +821,13 @@ public class LinkController extends SelectionController implements IExtension {
 		return shape;
 	}
 
-	public int getStandardConnectorAlpha() {
+	public int getStandardConnectorOpacity() {
 		final String standardAlpha = ResourceController.getResourceController().getProperty(RESOURCES_CONNECTOR_COLOR_ALPHA);
 		final int alpha = Integer.valueOf(standardAlpha);
 		return alpha;
 	}
 
-	public int getAlpha(ConnectorModel connectorModel) {
+	public int getOpacity(ConnectorModel connectorModel) {
 		return connectorModel.getAlpha();
     }
 
