@@ -41,7 +41,7 @@ public class NodeLinks implements IExtension {
 	public static final Object CONNECTOR = "connector";
 
 	/**
-	 * @param source2
+	 * @param node
 	 * @return
 	 */
 	public static NodeLinks createLinkExtension(final NodeModel node) {
@@ -89,7 +89,7 @@ public class NodeLinks implements IExtension {
 	        }
 	        return clones;
         }
-        else 
+        else
 			return Collections.<NodeLinkModel> emptyList();
 	}
 
@@ -133,7 +133,7 @@ public class NodeLinks implements IExtension {
                 }
                 catch (URISyntaxException e) {
 	                LogUtils.severe(e);
-                } 
+                }
 			}
 		}
 		return null;
@@ -193,7 +193,7 @@ public class NodeLinks implements IExtension {
 			return null;
 		}
 		final String linkString = link.toString();
-		if (linkString.startsWith("#")) {
+		if (linkString.startsWith("#ID")) {
 			final String id = linkString.substring(1);
 			if (model.getMap().getNodeForID(id) == null) {
 				return null;
