@@ -313,4 +313,11 @@ public class MapModel {
 		Controller.getCurrentModeController().getMapController().closeWithoutSaving(this);
 		return true;
 	}
+
+	public void beforeViewCreated() {
+	}
+
+	public boolean isUndoActionRunning() {
+		return false;
+	}
 }
