@@ -22,9 +22,7 @@ package org.freeplane.features.text;
 import java.awt.Color;
 import java.awt.Component;
 import java.awt.Font;
-import java.io.File;
 import java.net.URI;
-import java.net.URISyntaxException;
 import java.util.Collections;
 import java.util.LinkedList;
 import java.util.List;
@@ -70,7 +68,6 @@ public class TextController implements IExtension {
 	private final List<IContentTransformer> textTransformers;
 	protected final ModeController modeController;
 	private boolean nodeNumberingEnabled = true;
-	private static final String FILE_PROTOCOL = "file:";
 	public static final String MARK_TRANSFORMED_TEXT = "highlight_formulas";
 
 	public static boolean isMarkTransformedTextSet() {
@@ -425,24 +422,7 @@ public class TextController implements IExtension {
 
 	public URI toUri(final Object value, final NodeModel node, Object extension) {
 		final Object transformedObject = getTransformedObjectNoFormattingNoThrow(value, node, extension);
-		if (transformedObject instanceof URI)
-			return (URI)transformedObject;
-		final String objectAsFileReference;
-		if(transformedObject instanceof File) {
-			objectAsFileReference = TextController.FILE_PROTOCOL + ((File)transformedObject).getPath();
-		}
-		else if (transformedObject instanceof String) {
-			objectAsFileReference = (String) transformedObject;
-			if(!objectAsFileReference.startsWith(TextController.FILE_PROTOCOL))
-				return null;
-		}
-		else
-			return null;
-		try {
-			return LinkController.createURI(objectAsFileReference);
-		}
-		catch (URISyntaxException e) {
-			return null;
-		}
+		return LinkController.toUri(transformedObject);
 	}
+
 }
