@@ -26,7 +26,6 @@ import java.lang.reflect.InvocationTargetException;
 import java.net.MalformedURLException;
 import java.net.URI;
 import java.net.URL;
-
 import javax.swing.JComponent;
 import javax.swing.JPanel;
 import javax.swing.JScrollPane;
@@ -53,7 +52,6 @@ class AppletViewController extends FrameController implements IMapViewChangeList
 	private JComponent mComponentInSplitPane;
 	private JComponent mapContentBox;
 	private JScrollPane scrollPane;
-
 	public AppletViewController( final FreeplaneApplet applet, Controller controller,
 	                            final IMapViewManager mapViewController) {
 		super(controller, mapViewController, "");
@@ -114,7 +112,7 @@ class AppletViewController extends FrameController implements IMapViewChangeList
 		if (initialMapName != "") {
 			try {
 				final URL mapUrl = new URL(initialMapName);
-				getController().getModeController().getMapController().newMap(mapUrl);
+				getController().getModeController().getMapController().openMap(mapUrl);
 			}
 			catch (final Exception e) {
 				LogUtils.severe(e);
