@@ -6,8 +6,8 @@ import java.util.List;
 
 import org.freeplane.core.util.Compat;
 
-class CommandLineParser {
-    static class Options {
+public class CommandLineParser {
+    public static class Options {
         private static final String HELP_MESSAGE = //
                 "\nUsage:\n\tfreeplane.bat [options] [file1 [file2 ...]]\n" //
                 + "\n -X<menukey>   : execute menu item with key <menukey>." //
@@ -55,16 +55,7 @@ class CommandLineParser {
             menuItemsToExecute.add(item);
         }
 
-        /** leads to setting of system property 'nonInteractive' - check via
-         * <pre>
-         *   boolean nonInteractive = Boolean.parseBoolean(System.getProperty("nonInteractive"));
-         * </pre>
-         */
-        private void setNonInteractive(boolean b) {
-            nonInteractive = b;
-        }
-
-        boolean isNonInteractive() {
+        public boolean isNonInteractive() {
             return nonInteractive;
         }
 
@@ -87,7 +78,7 @@ class CommandLineParser {
         }
     }
 
-    static CommandLineParser.Options parse(String[] args, boolean firstRun) {
+    public static CommandLineParser.Options parse(String[] args) {
         CommandLineParser.Options result = new CommandLineParser.Options();
         if (args == null || args.length == 0 || !args[0].startsWith("-")) {
             result.setFilesToOpen(args);
@@ -108,7 +99,7 @@ class CommandLineParser {
                 }
             }
             else if (arg.startsWith("-N")) {
-                result.setNonInteractive(true);
+                result.nonInteractive = true;
                 // -NX mymenuitem is allowed
                 if (arg.length() > 2) {
                     args[i] = "-" + arg.substring(2);
@@ -128,8 +119,7 @@ class CommandLineParser {
                 else if (args.length > i + 1)
                     userdir = args[++i];
                 else {
-                    if (firstRun)
-                        System.err.println("option -U<userdir> misses its parameter");
+                	System.err.println("option -U<userdir> misses its parameter");
                 }
                 if (userdir != null) {
                     System.setProperty(Compat.FREEPLANE_USERDIR_PROPERTY, userdir);
@@ -154,7 +144,7 @@ class CommandLineParser {
         }
         for (; i != args.length; ++i)
             result.addFilesToOpen(args[i]);
-        if (result.isHelpRequested() && firstRun) {
+        if (result.isHelpRequested()) {
             System.out.println(result.getHelpMessage());
             System.exit(0);
         }
