@@ -1,21 +1,17 @@
 package org.freeplane.main.application;
 
-import java.io.File;
-import java.io.IOException;
-import java.io.ObjectInputStream;
-import java.io.ObjectOutputStream;
-import java.io.OutputStream;
-import java.io.RandomAccessFile;
-import java.net.ServerSocket;
-import java.net.Socket;
-import java.net.UnknownHostException;
-
 import org.apache.commons.lang.StringUtils;
 import org.freeplane.core.resources.ResourceController;
 import org.freeplane.core.util.Compat;
 import org.freeplane.core.util.LogUtils;
 import org.freeplane.main.application.CommandLineParser.Options;
 
+import java.io.*;
+import java.net.InetAddress;
+import java.net.ServerSocket;
+import java.net.Socket;
+import java.net.UnknownHostException;
+
 public class SingleInstanceManager {
 	private File lockFile = new File(Compat.getApplicationUserDirectory(), "single_instance.lock");
 	private boolean isSingleInstanceMode;
@@ -32,8 +28,7 @@ public class SingleInstanceManager {
 		isSingleInstanceForceMode =!runsHeadless && resourceController.getBooleanProperty("single_instance_force");
 	}
 
-	public void start(String[] args) {
-        final Options options = CommandLineParser.parse(args, false);
+	public void start(final Options options) {
         final String[] filesToLoad = options.getFilesToOpenAsArray();
 		if (isSingleInstanceMode && !options.hasMenuItemsToExecute()) {
 			initLockFile();
@@ -96,11 +91,7 @@ public class SingleInstanceManager {
 			LogUtils.info("Successfully notified first instance.");
 			return true;
 		}
-		catch (UnknownHostException e) {
-			LogUtils.severe(e.getMessage(), e);
-			return false;
-		}
-		catch (IOException e) {
+		catch (Exception e) {
 			LogUtils.warn("Error connecting to existing instance (stale lockfiles may cause this).", e);
 			return false;
 		}
@@ -109,7 +100,7 @@ public class SingleInstanceManager {
 	private boolean startAsMaster() {
 		try {
 			// port number 0: use any free socket
-			final ServerSocket socket = new ServerSocket(0, 10);
+			final ServerSocket socket = new ServerSocket(0, 10, InetAddress.getByName(null));
 			port = socket.getLocalPort();
 			LogUtils.info("Listening for application instances on socket " + port);
 			createLockFile();
