@@ -19,6 +19,8 @@
  */
 package org.freeplane.main.osgi;
 
+import java.awt.GraphicsEnvironment;
+import java.awt.Toolkit;
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.InputStream;
@@ -37,9 +39,13 @@ import org.freeplane.core.util.LogUtils;
 import org.freeplane.features.filter.FilterController;
 import org.freeplane.features.mode.Controller;
 import org.freeplane.features.mode.ModeController;
+import org.freeplane.main.application.ApplicationResourceController;
+import org.freeplane.main.application.CommandLineParser;
+import org.freeplane.main.application.CommandLineParser.Options;
 import org.freeplane.main.application.FreeplaneGUIStarter;
 import org.freeplane.main.application.FreeplaneStarter;
 import org.freeplane.main.application.SingleInstanceManager;
+import org.freeplane.main.application.protocols.freeplaneresource.Handler;
 import org.freeplane.main.headlessmode.FreeplaneHeadlessStarter;
 import org.freeplane.main.mindmapmode.stylemode.ExtensionInstaller;
 import org.freeplane.main.mindmapmode.stylemode.SModeControllerFactory;
@@ -56,7 +62,25 @@ import org.osgi.service.url.URLStreamHandlerService;
  * 05.01.2009
  */
 class ActivatorImpl implements BundleActivator {
-	private static final String HEADLESS_RUN_PROPERTY_NAME = FreeplaneStarter.class.getName() + ".headless";
+	private static void fixX11AppName() {
+		if(! System.getProperty("java.version").startsWith("1."))
+			return;
+		try {
+			Toolkit xToolkit = Toolkit.getDefaultToolkit();
+			if (xToolkit.getClass().getName().equals("sun.awt.X11.XToolkit"))
+			{
+				java.lang.reflect.Field awtAppClassNameField = xToolkit.getClass().getDeclaredField("awtAppClassName");
+				awtAppClassNameField.setAccessible(true);
+				awtAppClassNameField.set(xToolkit, "Freeplane");
+			}
+		} catch (NoSuchFieldException | SecurityException
+				| IllegalArgumentException | IllegalAccessException e) {
+			System.err.format("Couldn't set awtAppClassName: %s%n", e.getClass().getSimpleName() + ": " + e.getMessage());
+		}
+	}
+	
+	private static final String JAVA_HEADLESS_PROPERTY = "java.awt.headless";
+
 	private FreeplaneStarter starter;
 
 	private String[] getCallParameters() {
@@ -76,6 +100,7 @@ class ActivatorImpl implements BundleActivator {
 		return array;
 	}
 
+	@Override
 	public void start(final BundleContext context) throws Exception {
 		try {
 			final String userDirectory = System.getProperty("org.freeplane.user.dir");
@@ -94,8 +119,8 @@ class ActivatorImpl implements BundleActivator {
 	}
 
 	private void loadPlugins(final BundleContext context) {
-		final String resourceBaseDir = FreeplaneGUIStarter.getResourceBaseDir();
-		final File baseDir = new File(resourceBaseDir).getAbsoluteFile().getParentFile();
+		final String installationBaseDir = ApplicationResourceController.INSTALLATION_BASE_DIRECTORY;
+		final File baseDir = new File(installationBaseDir).getAbsoluteFile();
 		List<Bundle> loadedPlugins = new LinkedList<Bundle>();
 		loadPlugins(context, new File(baseDir, "plugins"), loadedPlugins);
 		final String freeplaneUserDirectory = Compat.getApplicationUserDirectory();
@@ -154,9 +179,10 @@ class ActivatorImpl implements BundleActivator {
 	}
 
 	private void startFramework(final BundleContext context) {
-        registerClasspathUrlHandler(context);
+        registerClasspathUrlHandler(context, ResourceController.FREEPLANE_RESOURCE_URL_PROTOCOL, new Handler());
+        registerClasspathUrlHandler(context, DataHandler.PROTOCOL, new DataHandler());
 		if (null == System.getProperty("org.freeplane.core.dir.lib", null)) {
-			final File root = new File(FreeplaneGUIStarter.getResourceBaseDir()).getAbsoluteFile().getParentFile();
+			final File root = new File(ApplicationResourceController.RESOURCE_BASE_DIRECTORY).getAbsoluteFile().getParentFile();
 			try {
 				String rootUrl = root.toURI().toURL().toString();
 				if (!rootUrl.endsWith("/")) {
@@ -169,9 +195,13 @@ class ActivatorImpl implements BundleActivator {
 			}
 		}
 		// initialize ApplicationController - SingleInstanceManager needs the configuration
-		starter =  createStarter();
-		final SingleInstanceManager singleInstanceManager = new SingleInstanceManager(starter);
-		singleInstanceManager.start(getCallParameters());
+		Options options = CommandLineParser.parse(getCallParameters());
+		if(options.isNonInteractive())
+			System.setProperty(JAVA_HEADLESS_PROPERTY, "true");
+
+		starter =  createStarter(options);
+		final SingleInstanceManager singleInstanceManager = new SingleInstanceManager(starter, GraphicsEnvironment.isHeadless());
+		singleInstanceManager.start(options);
 		if (singleInstanceManager.isSlave()) {
 			LogUtils.info("opened files in master - exiting now");
 			System.exit(0);
@@ -185,18 +215,16 @@ class ActivatorImpl implements BundleActivator {
 		installControllerExtensions(context, controller);
 		if ("true".equals(System.getProperty("org.freeplane.exit_on_start", null))) {
 			controller.getViewController().invokeLater(new Runnable() {
+				@Override
 				public void run() {
-					try {
-						Thread.sleep(1000);
-					}
-					catch (final InterruptedException e) {
-					}
+					Controller.getCurrentController().fireStartupFinished();
 					System.exit(0);
 				}
 			});
 			return;
 		}
 		controller.getViewController().invokeLater(new Runnable() {
+			@Override
 			public void run() {
 				final Bundle[] bundles = context.getBundles();
 				final HashSet<String> plugins = new HashSet<String>();
@@ -206,14 +234,14 @@ class ActivatorImpl implements BundleActivator {
 				}
 				FilterController.getController(controller).loadDefaultConditions();
 				starter.buildMenus(controller, plugins);
-				starter.createFrame(getCallParameters());
+				starter.createFrame();
 			}
 		});
 	}
-	
+
 	private static class OsgiExtentionInstaller implements ExtensionInstaller{
 		private final BundleContext context;
-		
+
 		public OsgiExtentionInstaller(BundleContext context) {
 			super();
 			this.context = context;
@@ -259,7 +287,7 @@ class ActivatorImpl implements BundleActivator {
 				e.printStackTrace();
 			}
 		}
-		
+
 	}
 
 	private void installControllerExtensions(final BundleContext context, final Controller controller) {
@@ -267,20 +295,24 @@ class ActivatorImpl implements BundleActivator {
 		SModeControllerFactory.getInstance().setExtensionInstaller(osgiExtentionInstaller);
 		osgiExtentionInstaller.installExtensions(controller);
 	}
+	
 
-	public FreeplaneStarter createStarter() {
-		if(Boolean.getBoolean(HEADLESS_RUN_PROPERTY_NAME))
+	public FreeplaneStarter createStarter(Options options) {
+		if(GraphicsEnvironment.isHeadless()) {
 			return new FreeplaneHeadlessStarter();
-		else
-			return new FreeplaneGUIStarter(getCallParameters());
+		} else {
+			fixX11AppName();
+			return new FreeplaneGUIStarter(options);
+		}
     }
 
-    private void registerClasspathUrlHandler(final BundleContext context) {
+	private void registerClasspathUrlHandler(final BundleContext context, String protocol, ConnectionHandler handler) {
         Hashtable<String, String[]> properties = new Hashtable<String, String[]>();
-        properties.put(URLConstants.URL_HANDLER_PROTOCOL, new String[] { ResourceController.FREEPLANE_RESOURCE_URL_PROTOCOL });
-        context.registerService(URLStreamHandlerService.class.getName(), new ResourcesUrlHandler(), properties);
+        properties.put(URLConstants.URL_HANDLER_PROTOCOL, new String[] { protocol });
+        context.registerService(URLStreamHandlerService.class.getName(), new DelegatingUrlHandlerService(handler), properties);
     }
 
+	@Override
 	public void stop(final BundleContext context) throws Exception {
 		starter.stop();
 		final Bundle[] bundles = context.getBundles();
