@@ -36,10 +36,13 @@ public class NodeListAction extends AFreeplaneAction {
 
 	public NodeListAction() {
 		super("NodeListAction");
-		nodeList = new NodeList(true, false, "nodelistwindow.configuration");
+		nodeList = new NodeListWithReplacement(NodeList.REMINDER_TEXT_WINDOW_TITLE_ALL_NODES,
+			false,
+			"nodelistwindow.configuration");
 	}
 
+	@Override
 	public void actionPerformed(final ActionEvent e) {
-		nodeList.startup();
+		nodeList.startup((node, reminder) -> node.hasVisibleContent());
 	}
 }
