@@ -541,7 +541,12 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 
     private String getValueForEdit(final int row, final int col) {
         final Object value = getValueAt(row, col);
-        return (value instanceof IFormattedObject ? ((IFormattedObject) value).getObject() : value).toString();
+        final Object object;
+		if (value instanceof IFormattedObject)
+			object = ((IFormattedObject) value).getObject();
+		else
+			object = value;
+        return object == null ? "" : object.toString();
     }
 
 
@@ -591,16 +596,29 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 	/**
 	 */
 	public void insertRow(final int row) {
+		int actuallyInsertedRow = row;
 		if (getModel() instanceof ExtendedAttributeTableModelDecorator) {
 			final ExtendedAttributeTableModelDecorator model = (ExtendedAttributeTableModelDecorator) getModel();
-			if (isEditing() && getCellEditor() != null && !getCellEditor().stopCellEditing()) {
-				return;
-			}
-			model.insertRow(row);
-			changeSelection(row, 0, false, false);
-			if (editCellAt(row, 0)) {
-				getEditorComponent().requestFocusInWindow();
+			if (isEditing()) {
+				final int editingRow = getEditingRow();
+				final int rowCount = getRowCount();
+				if (!getCellEditor().stopCellEditing()) {
+					return;
+				}
+				final int updatedRowCount = getRowCount();
+				if(updatedRowCount < rowCount && row >= editingRow) {
+					actuallyInsertedRow--;
+				}
 			}
+			insertRow(model, actuallyInsertedRow);
+		}
+	}
+
+	private void insertRow(final ExtendedAttributeTableModelDecorator model, final int row) {
+		model.insertRow(row);
+		changeSelection(row, 0, false, false);
+		if (editCellAt(row, 0)) {
+			getEditorComponent().requestFocusInWindow();
 		}
 	}
 
@@ -793,7 +811,6 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 		Component comp = null;
 		int maxCellWidth = 2 * (int) (Math.ceil(getFont().getSize2D() / UITools.FONT_SCALE_FACTOR +  EXTRA_HEIGHT));
 		int rowCount = getRowCount();
-		boolean isInsideNodeView = getNodeViewAncestor() != null;
 		if(rowCount > 0) {
 			for (int col = 0; col < 2; col++) {
 				for (int row = 0; row < rowCount; row++) {
@@ -942,8 +959,8 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 		if (rowCount == 0) {
 			return;
 		}
-		final float fontSize = (float) getFont().getMaxCharBounds(((Graphics2D)getGraphics()).getFontRenderContext()).getHeight();
 		final float zoom = getZoom();
+		final float fontSize = (float) getFont().getMaxCharBounds(((Graphics2D)getGraphics()).getFontRenderContext()).getHeight() * zoom;
 		final int extraHeight = (int)(zoom * EXTRA_HEIGHT + 0.7f);
 		int rowHeight = Math.max(1, (int)fontSize + extraHeight);
 		for (int i = 0; i <  rowCount; i++) {
