@@ -78,7 +78,7 @@ public class DefaultNodeMouseMotionListener implements IMouseListener {
 					if(iconController.onIconClicked(node, uiIcon))
 						return;
 				}
-				else if (component.isClickableLink(e.getX())) {
+				if (component.isClickableLink(e.getX())) {
 					LinkController.getController(mc).loadURL(node, e);
 					e.consume();
 					return;
@@ -116,10 +116,8 @@ public class DefaultNodeMouseMotionListener implements IMouseListener {
 				}
 			}
 		}
-		final boolean inFoldingRegion = isInFoldingRegion(e);
-		if ((plainEvent && inFoldingRegion
-				|| (inFoldingRegion || inside) && Compat.isCtrlShiftEvent(e))
-		        && !nodeSelector.shouldSelectOnClick(e)) {
+
+		if (inside && Compat.isCtrlShiftEvent(e) && !nodeSelector.shouldSelectOnClick(e)) {
 			doubleClickTimer.cancel();
 			mapController.toggleFolded(node);
 			e.consume();
@@ -149,6 +147,15 @@ public class DefaultNodeMouseMotionListener implements IMouseListener {
 		nodeSelector.extendSelection(e);
 	}
 
+
+	private void toggleFolded(final MouseEvent e) {
+		final NodeView nodeView = nodeSelector.getRelatedNodeView(e);
+		if(nodeView!= null) {
+			doubleClickTimer.cancel();
+			nodeView.getMap().getModeController().getMapController().toggleFolded(nodeView.getModel());
+		}
+	}
+
 	@Override
 	public void mouseEntered(final MouseEvent e) {
 		if (nodeSelector.isRelevant(e)) {
@@ -204,7 +211,12 @@ public class DefaultNodeMouseMotionListener implements IMouseListener {
 		final MapView mapView = MapView.getMapView(e.getComponent());
 		mapView.select();
 		doubleClickTimer.cancel();
-		showPopupMenu(e);
+		if (e.isPopupTrigger())
+			showPopupMenu(e);
+		else if(e.getButton() == MouseEvent.BUTTON1
+				&& Compat.isPlainEvent(e)
+				&& isInFoldingRegion(e))
+			toggleFolded(e);
 	}
 
 	@Override
