@@ -6,6 +6,8 @@ public interface Font extends FontRO {
 
 	void resetItalic();
 
+	void resetStrikedThrough();
+
 	void resetName();
 
 	void resetSize();
@@ -14,6 +16,8 @@ public interface Font extends FontRO {
 
 	void setItalic(boolean italic);
 
+	void setStrikedThrough(boolean strikedThrough);
+
 	void setName(String name);
 
 	void setSize(int size);
