@@ -1,6 +1,7 @@
 package org.freeplane.plugin.bugreport;
 
 import java.awt.Dimension;
+import java.awt.GraphicsEnvironment;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.io.BufferedReader;
@@ -345,7 +346,7 @@ public class ReportGenerator extends StreamHandler {
 		final ResourceController resourceController = ResourceController.getResourceController();
 		String option = resourceController.getProperty(OPTION, BugReportDialogManager.ASK);
 		if (option.equals(BugReportDialogManager.ASK)) {
-			if (resourceController.getBooleanProperty("org.freeplane.plugin.bugreport.dialog.disabled") || isHeadlessMode())
+			if (resourceController.getBooleanProperty("org.freeplane.plugin.bugreport.dialog.disabled") || GraphicsEnvironment.isHeadless())
 				return BugReportDialogManager.DENIED;
 			String question = TextUtils.getText("org.freeplane.plugin.bugreport.question");
 			if (!question.startsWith("<html>")) {
@@ -382,10 +383,6 @@ public class ReportGenerator extends StreamHandler {
 		return option;
 	}
 
-	private boolean isHeadlessMode() {
-		return Controller.getCurrentController().getViewController().isHeadless();
-	}
-
 	private String sendReport(final Map<String, String> reportFields) {
 		try {
 			// Construct data
