@@ -2,9 +2,11 @@ package org.freeplane.plugin.script;
 
 import java.util.Hashtable;
 
+import org.freeplane.api.Controller;
 import org.freeplane.features.mode.ModeController;
 import org.freeplane.features.mode.mindmapmode.MModeController;
 import org.freeplane.main.osgi.IModeControllerExtensionProvider;
+import org.freeplane.plugin.script.proxy.ScriptUtils;
 import org.osgi.framework.BundleActivator;
 import org.osgi.framework.BundleContext;
 
@@ -13,21 +15,25 @@ public class Activator implements BundleActivator {
 	 * (non-Javadoc)
 	 * @see org.osgi.framework.BundleActivator#start(org.osgi.framework.BundleContext)
 	 */
+	@Override
 	public void start(final BundleContext context) throws Exception {
 		final Hashtable<String, String[]> props = new Hashtable<String, String[]>();
 		props.put("mode", new String[] { MModeController.MODENAME });
 		context.registerService(IModeControllerExtensionProvider.class.getName(),
 		    new IModeControllerExtensionProvider() {
-			    public void installExtension(ModeController modeController) {
+			    @Override
+				public void installExtension(ModeController modeController) {
 				    new ScriptingRegistration(modeController);
 			    }
 		    }, props);
+		context.registerService(Controller.class.getName(), ScriptUtils.c(), new Hashtable<String, String[]>());
 	}
 
 	/*
 	 * (non-Javadoc)
 	 * @see org.osgi.framework.BundleActivator#stop(org.osgi.framework.BundleContext)
 	 */
+	@Override
 	public void stop(final BundleContext context) throws Exception {
 	}
 }
