@@ -1,8 +1,5 @@
 package org.freeplane.plugin.script;
 
-import org.freeplane.core.util.HtmlUtils;
-import org.freeplane.core.util.TextUtils;
-
 public class CyclicScriptReferenceException extends RuntimeException {
 	public CyclicScriptReferenceException(String message) {
 		super(message);
