@@ -23,9 +23,9 @@ import java.io.File;
 import java.io.PrintStream;
 import java.security.AccessControlException;
 import java.security.AccessController;
+import java.security.PrivilegedAction;
 import java.security.PrivilegedActionException;
 import java.security.PrivilegedExceptionAction;
-import java.util.Map.Entry;
 import java.util.regex.Matcher;
 
 import javax.swing.SwingUtilities;
@@ -38,12 +38,11 @@ import org.codehaus.groovy.runtime.InvokerHelper;
 import org.freeplane.features.map.IMapSelection;
 import org.freeplane.features.map.NodeModel;
 import org.freeplane.features.mode.Controller;
-import org.freeplane.plugin.script.proxy.ProxyFactory;
+import org.freeplane.plugin.script.proxy.ScriptUtils;
 
 import groovy.lang.Binding;
 import groovy.lang.GroovyRuntimeException;
 import groovy.lang.Script;
-import org.freeplane.plugin.script.proxy.ScriptUtils;
 
 /**
  * Special scripting implementation for Groovy.
@@ -107,9 +106,14 @@ public class GroovyScript implements IScript {
             try {
                 trustedCompileAndCache(outStream);
                 Thread.currentThread().setContextClassLoader(scriptClassLoader);
-                updateBinding(node, scriptContext);
+                FreeplaneScriptBaseClass scriptWithBinding = AccessController.doPrivileged(new PrivilegedAction<FreeplaneScriptBaseClass>() {
+					@Override
+					public FreeplaneScriptBaseClass run() {
+						return compiledScript.withBinding(node, scriptContext);
+					}
+				}); 
                 System.setOut(outStream);
-				final Object result = compiledScript.run();
+				final Object result = scriptWithBinding.run();
 				return result;
             } finally {
                 System.setOut(oldOut);
@@ -124,7 +128,7 @@ public class GroovyScript implements IScript {
             throw new RuntimeException(e);
         } catch (final Throwable e) {
 			IMapSelection selection = Controller.getCurrentController().getSelection();
-			if (selection != null && ! node.equals(selection.getSelected()) && node.hasVisibleContent()) {
+			if (selection != null && node != null && ! node.equals(selection.getSelected()) && node.hasVisibleContent()) {
 				SwingUtilities.invokeLater(new Runnable() {
 					@Override
 					public void run() {
@@ -187,6 +191,7 @@ public class GroovyScript implements IScript {
                 } else {
                     throw new IllegalArgumentException();
                 }
+                compiledScript.setScript(script);
                 compileTimeStrategy.scriptCompiled();
                 return compiledScript;
             } catch (Throwable e) {
@@ -216,16 +221,6 @@ public class GroovyScript implements IScript {
         }
     }
 
-    private void updateBinding(final NodeModel node, ScriptContext scriptContext) {
-    	Binding binding = compiledScript.getBinding();
-        binding.setVariable("c", ProxyFactory.createController(scriptContext));
-        binding.setVariable("node", ProxyFactory.createNode(node, scriptContext));
-	    for (Entry<String, Object> entry : ScriptingConfiguration.getStaticProperties().entrySet()) {
-            binding.setProperty(entry.getKey(), entry.getValue());
-        }
-		compiledScript.setBinding(binding);
-    }
-
     private Binding createBindingForCompilation() {
         final Binding binding = new Binding();
         binding.setVariable("script", script);
