@@ -1,13 +1,9 @@
 /**
- * 
+ *
  */
 package org.freeplane.plugin.script.proxy;
 
-import groovy.lang.Closure;
-import groovy.lang.MissingMethodException;
-
 import java.util.ArrayList;
-import java.util.Collection;
 import java.util.Collections;
 import java.util.Iterator;
 import java.util.LinkedHashMap;
@@ -15,6 +11,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.Vector;
 
+import org.freeplane.api.AttributeCondition;
 import org.freeplane.features.attribute.Attribute;
 import org.freeplane.features.attribute.AttributeController;
 import org.freeplane.features.attribute.NodeAttributeTableModel;
@@ -22,33 +19,53 @@ import org.freeplane.features.attribute.mindmapmode.MAttributeController;
 import org.freeplane.features.format.IFormattedObject;
 import org.freeplane.features.map.INodeView;
 import org.freeplane.features.map.NodeModel;
+import org.freeplane.features.text.TextController;
 import org.freeplane.plugin.script.ScriptContext;
+import org.freeplane.plugin.script.proxy.Proxy.Attributes;
 import org.freeplane.view.swing.map.NodeView;
 
+import groovy.lang.Closure;
+import groovy.lang.MissingMethodException;
+
 class AttributesProxy extends AbstractProxy<NodeModel> implements Proxy.Attributes {
-	AttributesProxy(final NodeModel delegate, final ScriptContext scriptContext) {
+	private boolean transformsValues;
+
+	AttributesProxy(final NodeModel delegate, final ScriptContext scriptContext, final boolean transformsValues) {
 		super(delegate, scriptContext);
+		this.transformsValues = transformsValues;
 	}
 
-    public boolean containsKey(String name) {
+    @Override
+	public boolean containsKey(String name) {
         final int index = findFirst(name);
         return (index != -1);
     }
 
+	@Override
 	@Deprecated
 	public Object get(final String name) {
 		return getFirst(name);
 	}
 
+	@Override
 	public Object getFirst(final String name) {
 		final int index = findFirst(name);
 		if (index == -1) {
 			return null;
 		}
 		final NodeAttributeTableModel attributeTableModel = getNodeAttributeTableModel();
-		return attributeTableModel.getAttribute(index).getValue();
+		final Attribute attribute = attributeTableModel.getAttribute(index);
+		reportAttributeAccess(attribute);
+		return getAttributeValue(attribute);
 	}
 
+	private void reportAttributeAccess(Attribute attribute) {
+		ScriptContext scriptContext = getScriptContext();
+		if(scriptContext != null)
+			scriptContext.accessAttribute(getDelegate(), attribute);
+	}
+
+	@Override
 	public List<Object> getAll(final String name) {
 		final NodeAttributeTableModel attributeTableModel = getNodeAttributeTableModel();
 		if (attributeTableModel == null) {
@@ -57,12 +74,14 @@ class AttributesProxy extends AbstractProxy<NodeModel> implements Proxy.Attribut
 		final ArrayList<Object> result = new ArrayList<Object>();
 		for (final Attribute attribute : attributeTableModel.getAttributes()) {
 			if (attribute.getName().equals(name)) {
-				result.add(attribute.getValue());
+				reportAttributeAccess(attribute);
+				result.add(getAttributeValue(attribute));
 			}
 		}
 		return result;
 	}
 
+	@Override
 	public List<String> getNames() {
 		final NodeAttributeTableModel attributeTableModel = getNodeAttributeTableModel();
 		if (attributeTableModel == null) {
@@ -75,11 +94,13 @@ class AttributesProxy extends AbstractProxy<NodeModel> implements Proxy.Attribut
 		return result;
 	}
 
+	@Override
 	@Deprecated
 	public List<String> getAttributeNames() {
 		return getNames();
 	}
-	
+
+	@Override
 	public List<? extends Convertible> getValues() {
 		final NodeAttributeTableModel attributeTableModel = getNodeAttributeTableModel();
 		if (attributeTableModel == null) {
@@ -87,11 +108,30 @@ class AttributesProxy extends AbstractProxy<NodeModel> implements Proxy.Attribut
 		}
 		final ArrayList<Convertible> result = new ArrayList<Convertible>(attributeTableModel.getRowCount());
 		for (final Attribute a : attributeTableModel.getAttributes()) {
-			result.add(ProxyUtils.attributeValueToConvertible(getDelegate(), getScriptContext(), a.getValue()));
+			reportAttributeAccess(a);
+			result.add(ProxyUtils.attributeValueToConvertible(getDelegate(), getScriptContext(), getAttributeValue(a)));
 		}
 		return result;
 	}
 
+	@Override
+	public Proxy.Attributes getTransformed() {
+		return withTransformedValues(getDelegate(), getScriptContext());
+	}
+
+
+
+	private Object getAttributeValue(final Attribute a) {
+		final Object value = a.getValue();
+		if(transformsValues) {
+			final Object content = TextController.getController().getTransformedObjectNoFormattingNoThrow(value, getDelegate(), null);
+			return content;
+		}
+		else
+			return value;
+	}
+
+	@Override
 	public Map<String, Object> getMap() {
 		final NodeAttributeTableModel attributeTableModel = getNodeAttributeTableModel();
 		if (attributeTableModel == null) {
@@ -99,28 +139,24 @@ class AttributesProxy extends AbstractProxy<NodeModel> implements Proxy.Attribut
 		}
 		final LinkedHashMap<String, Object> result = new LinkedHashMap<String, Object>(attributeTableModel.getRowCount());
 		for (final Attribute a : attributeTableModel.getAttributes()) {
-			result.put(a.getName(), a.getValue());
+			result.put(a.getName(), getAttributeValue(a));
 		}
 		return result;
     }
 
-	public List<? extends Convertible> findValues(Closure<Boolean> closure) {
+	@Override
+	public List<? extends Convertible> findValues(final Closure<Boolean> closure) {
 		try {
-			final NodeAttributeTableModel attributeTableModel = getNodeAttributeTableModel();
-			if (attributeTableModel == null) {
-				return Collections.emptyList();
-			}
-			final ArrayList<Convertible> result = new ArrayList<Convertible>(
-			    attributeTableModel.getRowCount());
-			for (final Attribute a : attributeTableModel.getAttributes()) {
-				final Object bool = closure.call(new Object[] { a.getName(), a.getValue() });
-				if (result == null) {
-					throw new RuntimeException("findValues(): closure returned null instead of boolean/Boolean");
+			return findValues(new AttributeCondition() {
+				@Override
+				public boolean check(String attributeName, Object attributeValue) {
+					final Object result = closure.call(attributeName, attributeValue);
+					if (result == null) {
+						throw new RuntimeException("findValues(): closure returned null instead of boolean/Boolean");
+					}
+					return (Boolean) result;
 				}
-				if ((Boolean) bool)
-					result.add(ProxyUtils.attributeValueToConvertible(getDelegate(), getScriptContext(), a.getValue()));
-			}
-			return result;
+			});
 		}
 		catch (final MissingMethodException e) {
 			throw new RuntimeException("findValues(): closure needs to accept two args and must return boolean/Boolean"
@@ -132,6 +168,25 @@ class AttributesProxy extends AbstractProxy<NodeModel> implements Proxy.Attribut
 		}
 	}
 
+	@Override
+	public List<? extends Convertible> findValues(AttributeCondition condition) {
+		final NodeAttributeTableModel attributeTableModel = getNodeAttributeTableModel();
+		if (attributeTableModel == null) {
+			return Collections.emptyList();
+		}
+		final ArrayList<Convertible> result = new ArrayList<Convertible>(
+				attributeTableModel.getRowCount());
+		for (final Attribute a : attributeTableModel.getAttributes()) {
+			final Object transformedAttributeValue = getAttributeValue(a);
+			if (condition.check(a.getName(), transformedAttributeValue)) {
+				reportAttributeAccess(a);
+				result.add(ProxyUtils.attributeValueToConvertible(getDelegate(), getScriptContext(), transformedAttributeValue));
+			}
+		}
+		return result;
+	}
+
+	@Override
 	public Object get(final int index) {
 		return getAndCheckNodeAttributeTableModelForIndex(index, "get:").getValue(index);
 	}
@@ -144,32 +199,38 @@ class AttributesProxy extends AbstractProxy<NodeModel> implements Proxy.Attribut
         return attributeTableModel;
     }
 
-    public String getKey(int index) {
+    @Override
+	public String getKey(int index) {
 		return getAndCheckNodeAttributeTableModelForIndex(index, "getKey:").getAttribute(index).getName();
     }
 
+	@Override
 	public void set(final int index, final Object value) {
 		final NodeAttributeTableModel attributeTableModel = getAndCheckNodeAttributeTableModelForIndex(index, "set1:");
         String oldPattern = getOldValueFormatPattern(attributeTableModel, index);
-		getAttributeController().performSetValueAt(attributeTableModel, ProxyUtils.transformObject(value, oldPattern), index, 1);
+		getAttributeController().performSetValueAt(getDelegate(), attributeTableModel, ProxyUtils.transformObject(value, oldPattern), index, 1);
 	}
 
+	@Override
 	public void set(final int index, final String name, final Object value) {
         final NodeAttributeTableModel attributeTableModel = getAndCheckNodeAttributeTableModelForIndex(index, "set2:");
         String oldPattern = getOldValueFormatPattern(attributeTableModel, index);
 		getAttributeController().setAttribute(getDelegate(), index, new Attribute(name, ProxyUtils.transformObject(value, oldPattern)));
 	}
 
+	@Override
 	public void set(final int index, final String name, final Object value, String pattern) {
 		getAttributeController().setAttribute(getDelegate(), index, new Attribute(name, ProxyUtils.transformObject(value, pattern)));
 	}
 
+	@Override
 	public void setFormat(final int index, String pattern) {
 		final NodeAttributeTableModel attributeTableModel = getAndCheckNodeAttributeTableModelForIndex(index, "set1:");
 		final Object value = attributeTableModel.getAttribute(index).getValue();
-		getAttributeController().performSetValueAt(attributeTableModel, ProxyUtils.transformObject(value, pattern), index, 1);
+		getAttributeController().performSetValueAt(getDelegate(), attributeTableModel, ProxyUtils.transformObject(value, pattern), index, 1);
 	}
 
+	@Override
 	public int findFirst(final String name) {
 		final List<String> attributeNames = getAttributeNames();
 		for (int i = 0; i < attributeNames.size(); i++) {
@@ -180,11 +241,13 @@ class AttributesProxy extends AbstractProxy<NodeModel> implements Proxy.Attribut
 		return -1;
 	}
 
+	@Override
 	@Deprecated
 	public int findAttribute(final String name) {
 		return findFirst(name);
 	}
 
+	@Override
 	@Deprecated
 	public boolean remove(final String name) {
 		final int index = findFirst(name);
@@ -195,6 +258,7 @@ class AttributesProxy extends AbstractProxy<NodeModel> implements Proxy.Attribut
 		return true;
 	}
 
+	@Override
 	public boolean removeAll(final String name) {
 		final NodeAttributeTableModel attributeTableModel = getNodeAttributeTableModel();
 		if (attributeTableModel == null) {
@@ -214,11 +278,13 @@ class AttributesProxy extends AbstractProxy<NodeModel> implements Proxy.Attribut
 		return !toRemove.isEmpty();
 	}
 
+	@Override
 	public void remove(final int index) {
         getAndCheckNodeAttributeTableModelForIndex(index, "remove:");
 		getAttributeController().removeAttribute(getDelegate(), index);
 	}
 
+	@Override
 	public void clear() {
 		final NodeAttributeTableModel attributeTableModel = getNodeAttributeTableModel();
 		final int size = attributeTableModel.getRowCount();
@@ -227,6 +293,7 @@ class AttributesProxy extends AbstractProxy<NodeModel> implements Proxy.Attribut
 		}
 	}
 
+	@Override
 	public void set(final String name, final Object value) {
 		final int index = findFirst(name);
 		if (index == -1) {
@@ -245,16 +312,19 @@ class AttributesProxy extends AbstractProxy<NodeModel> implements Proxy.Attribut
         return (value instanceof IFormattedObject) ? ((IFormattedObject) value).getPattern() : null;
     }
 
-    public void add(final String name, final Object value) {
+    @Override
+	public void add(final String name, final Object value) {
 		final Attribute attribute = new Attribute(name, ProxyUtils.transformObject(value, null));
 		getAttributeController().addAttribute(getDelegate(), attribute);
 	}
 
-    public void add(final String name, final Object value, String pattern) {
+    @Override
+	public void add(final String name, final Object value, String pattern) {
 		final Attribute attribute = new Attribute(name, ProxyUtils.transformObject(value, pattern));
 		getAttributeController().addAttribute(getDelegate(), attribute);
 	}
 
+	@Override
 	public int size() {
 		final NodeAttributeTableModel attributeTableModel = getNodeAttributeTableModel();
 		if (attributeTableModel == null) {
@@ -262,7 +332,8 @@ class AttributesProxy extends AbstractProxy<NodeModel> implements Proxy.Attribut
 		}
 		return attributeTableModel.getRowCount();
 	}
-	
+
+	@Override
 	public boolean isEmpty() {
 		return size() == 0;
 	}
@@ -290,8 +361,9 @@ class AttributesProxy extends AbstractProxy<NodeModel> implements Proxy.Attribut
 			}
 		}
 	}
-    
-    @SuppressWarnings("unchecked")
+
+    @Override
+	@SuppressWarnings("unchecked")
     public Iterator<Map.Entry<String, Object>> iterator() {
         final NodeAttributeTableModel attributeTableModel = getNodeAttributeTableModel();
         if (attributeTableModel == null) {
@@ -317,12 +389,12 @@ class AttributesProxy extends AbstractProxy<NodeModel> implements Proxy.Attribut
 
                     @Override
                     public Object getValue() {
-                        return attribute.getValue();
+                        return getAttributeValue(attribute);
                     }
 
                     @Override
                     public Object setValue(Object value) {
-                        final Object oldValue = attribute.getValue();
+                        final Object oldValue = getValue();
                         attribute.setValue(value);
                         return oldValue;
                     }
@@ -336,4 +408,12 @@ class AttributesProxy extends AbstractProxy<NodeModel> implements Proxy.Attribut
             }
         };
     }
+
+	static Attributes withRawValues(NodeModel delegate, ScriptContext scriptContext) {
+		return new AttributesProxy(delegate, scriptContext, false);
+	}
+
+	static Attributes withTransformedValues(NodeModel delegate, ScriptContext scriptContext) {
+		return new AttributesProxy(delegate, scriptContext, true);
+	}
 }
