@@ -20,25 +20,28 @@
  */
 package org.freeplane.plugin.svg;
 
-import java.io.BufferedOutputStream;
-import java.io.File;
-import java.io.FileOutputStream;
-import java.io.OutputStreamWriter;
-
 import org.apache.batik.svggen.SVGGeneratorContext;
 import org.apache.batik.svggen.SVGGraphics2D;
 import org.freeplane.core.resources.ResourceController;
 import org.freeplane.core.ui.components.UITools;
 import org.freeplane.features.export.mindmapmode.ExportController;
 import org.freeplane.features.map.MapModel;
+import org.freeplane.features.map.NodeModel;
 import org.freeplane.features.mode.Controller;
 import org.freeplane.view.swing.map.MapView;
 import org.w3c.dom.Document;
 
+import java.io.BufferedOutputStream;
+import java.io.File;
+import java.io.FileOutputStream;
+import java.io.OutputStreamWriter;
+import java.util.List;
+
 class ExportSvg extends ExportVectorGraphic {
 	private static final String SVG_EMBED_FONTS = "org.freeplane.plugin.svg.export.svg.embed_fonts";
 
-	public void export(MapModel map, File chosenFile) {
+	public void export(List<NodeModel> branches, File chosenFile) {
+		MapModel map = branches.get(0).getMap();
 		if (!ExportController.getContoller().checkCurrentMap(map)){
 			return;
 		}
